@@ -1,6 +1,6 @@
 package Mojolicious::Plugin::DevexpressHelpers;
-$Mojolicious::Plugin::DevexpressHelpers::VERSION = '0.163572';
-#ABSTRACT: Add some helpers to add and configure Devexpress controls
+our $VERSION = '0.01';
+
 use Modern::Perl;
 use Mojo::Base 'Mojolicious::Plugin';
 use Mojolicious::Plugin::DevexpressHelpers::Helpers;
@@ -10,26 +10,28 @@ use MojoX::AlmostJSON;
 
 
 sub register {
-    my ( $self, $app, $args ) = @_;
-
-    $args->{'tag_camelcase'} //= 1;
-    $args->{'tag_prefix'}    //= 'dx';
-    Mojolicious::Plugin::DevexpressHelpers::Helpers->register( $app, $args );
-
+    my ($self, $app, $args) = @_;
+    
+    #TODO: add assetpack
+    #plugin "AssetPack";
+    #app->asset( ... );
+    
+    my $tp = $args->{'tag_prefix'} // 'dx';
+    
+    $app->helper( 'dxbuild' => \&Mojolicious::Plugin::DevexpressHelpers::Helpers::dxbuild );
+    $app->helper( $tp.'button' => \&Mojolicious::Plugin::DevexpressHelpers::Helpers::dxbutton );
+    $app->helper( $tp.'datagrid' => \&Mojolicious::Plugin::DevexpressHelpers::Helpers::dxdatagrid );
+    
     #make json boolean easier to write within templates
-    $app->helper( 'true'  => \&MojoX::AlmostJSON::true );
+    $app->helper( 'true' => \&MojoX::AlmostJSON::true );
     $app->helper( 'false' => \&MojoX::AlmostJSON::false );
-
-    $app->hook(
-        before_dispatch => sub {
-            my $c = shift;
-
-            #create a new object that will help to generate binding for dx controls
-            $c->stash( 'dxHelper' =>
-                    Mojolicious::Plugin::DevexpressHelpers::Helpers->new );
-        }
-    );
-
+    
+    $app->hook(before_dispatch => sub{
+        my $c = shift;
+        #create a new object that will help to generate binding for dx controls
+        $c->stash('dxHelper' => Mojolicious::Plugin::DevexpressHelpers::Helpers->new );
+    });
+    
 }
 
 
@@ -43,15 +45,17 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::DevexpressHelpers - Add some helpers to add and configure Devexpress controls
+Mojolicious::Plugin::DevexpressHelpers
 
 =head1 VERSION
 
-version 0.163572
+version 1.151250
 
 =head1 SYNOPSIS
 
-Add some helpers to add and configure Devexpress controls in templates.
+Quick summary of what the module does.
+
+Perhaps a little code snippet.
 
     plugin 'DevexpressHelpers' => {
             dx_path => 'c:/Program Files (x86)/DevExpress 14.2/DevExtreme/Sources/Lib',
@@ -60,6 +64,11 @@ Add some helpers to add and configure Devexpress controls in templates.
         
     ...
     %= dxbutton 'My button' => '/my/action'
+    %= dxbutton 'My button' => q{function (){ alert('on_clicked!') }};
+    %= dxbutton 'My button' => { 
+            onClick => q{function (){ alert('on_clicked!') }},
+            class => [qw( my_class1 my_class2 )],
+        };
 
 =head1 NAME
 
@@ -67,7 +76,7 @@ Mojolicious::Plugin::DevexpressHelpers - Add some helpers to add and configure D
 
 =head1 HELPERS
 
-See L<Mojolicious::Plugin::DevexpressHelpers::Helpers>.
+A list of functions are exported by default.
 
 =head2 register
 
